@@ -3,7 +3,7 @@ package WWW::Proxy4FreeCom;
 use warnings;
 use strict;
 
-our $VERSION = '1.003';
+our $VERSION = '1.004001'; # VERSION
 
 use Carp;
 use URI;
@@ -93,7 +93,7 @@ sub _parse_proxy_list {
                 uptime  online_since  last_test
             /} = map "$_", map $_->text, ( $tr->find('td')->each )[ 3..8 ];
 
-            $tds{domain} = $tds{domain}->find('a')->text;
+            $tds{domain} = $tds{domain}->find('a')->map('text')->join;
             $tds{ $_ } = $tds{ $_ } =~ /on/ ? 1 : 0
                 for qw/features_hian  features_ssl/;
 
@@ -130,6 +130,8 @@ WWW::Proxy4FreeCom - fetch proxy list from http://proxy4free.com/
 
 =head1 SYNOPSIS
 
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-code.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
     use strict;
     use warnings;
     use WWW::Proxy4FreeCom;
@@ -142,6 +144,8 @@ WWW::Proxy4FreeCom - fetch proxy list from http://proxy4free.com/
     printf "%-40s (last tested %s ago)\n", @$_{ qw(domain last_test) }
         for @$proxies;
 
+=for html  </div></div>
+
 =head1 DESCRIPTION
 
 The module provides means to fetch proxy list
@@ -195,7 +199,7 @@ set to as well as C<agent> argument is set to mimic Firefox.
 
     ->new( debug => 1 );
 
-When C<get_list()> is called any unsuccessfull page retrievals will be
+When C<get_list()> is called any unsuccessful page retrievals will be
 silently ignored. Setting C<debug> argument to a true value will C<carp()>
 any network errors if they occur.
 
@@ -258,7 +262,7 @@ return a human-readable error message explaining the failure.
 
     my $last_list_ref = $prox->list;
 
-Must be called after a successfull call to C<get_list()>. Takes
+Must be called after a successful call to C<get_list()>. Takes
 no arguments, returns the same arrayref of hashrefs as
 last call to C<get_list()> returned.
 
@@ -283,50 +287,41 @@ Returns a currently set debug value, when called with an optional argument
 (which can be either a true or false value) will set debug to that value.
 See C<debug> argument to constructor for more information.
 
-=head1 AUTHOR
+=for html <div style="background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/hr.png);height: 18px;"></div>
 
-'Zoffix, C<< <'zoffix at cpan.org'> >>
-(L<http://zoffix.com>, L<http://haslayout.net>)
+=head1 REPOSITORY
+
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-github.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/WWW-Proxy4FreeCom>
+
+=for html  </div></div>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-www-proxy4freecom at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Proxy4FreeCom>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-bugs.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
 
-=head1 SUPPORT
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/WWW-Proxy4FreeCom/issues>
 
-You can find documentation for this module with the perldoc command.
+If you can't access GitHub, you can email your request
+to C<bug-www-proxy4freecom at rt.cpan.org>
 
-    perldoc WWW::Proxy4FreeCom
+=for html  </div></div>
 
-You can also look for information at:
+=head1 AUTHOR
 
-=over 4
+=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-author.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
 
-=item * RT: CPAN's request tracker
+=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/ZOFFIX"> <img src="http://www.gravatar.com/avatar/328e658ab6b08dfb5c106266a4a5d065?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F627d83ef9879f31bdabf448e666a32d5" alt="ZOFFIX" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">ZOFFIX</span> </a> </span>
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Proxy4FreeCom>
+=for html  </div></div>
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=head1 LICENSE
 
-L<http://annocpan.org/dist/WWW-Proxy4FreeCom>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/WWW-Proxy4FreeCom>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/WWW-Proxy4FreeCom>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 'Zoffix, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
 =cut
